Module models

Module models 

Structs

AgentManagerAuthRequest
AgentManagerAuthResponse
AppHeartbeatRequest
AppHeartbeatResponse
App Heartbeat Response
GetFortanixAttestationRequest
GetFortanixAttestationResponse
IssueCertificateRequest
IssueCertificateResponse
NodeLocalData
Node local data
TargetInfo
VersionResponse
Agent Version

Enums

ResponseStatus
Status string for a response Enumeration of values. Since this enum’s variants do not hold data, we can easily define them them as #[repr(C)] which helps with FFI.
TaskStatusType
Status string for a task Enumeration of values. Since this enum’s variants do not hold data, we can easily define them them as #[repr(C)] which helps with FFI.